@@ -202,6 +202,49 @@ class Agent(Insight, Channel, Catalog, Dataset):
         response.raise_for_status()
         r = response.json()
 
+
+    def query(self, dataset_slug, fields:list, filters:list=[], sorted_by:list=[]):
+
+        dataset_id = self.get_dataset_by_slug(self._agentId, dataset_slug)
+        body = {
+            "agentId": self._agentId,
+            "datasetId": dataset_id,
+            "fields": fields,
+            "sortedBy": sorted_by,
+            "filters": filters
+        }
+
+        url = self.smart_insight_url = "/composed_queries/sdk"
+
+        s = requests.Session()
+        s.keep_alive = False
+        retries = Retry(total=5, backoff_factor=1, status_forcelist=[502, 503, 504])
+        s.mount('https://', HTTPAdapter(max_retries=retries))
+
+        headers = {"Authorization": "Bearer" + " " + self._token}
+        response = s.post(url=url, json=body, headers=headers)
+        response.raise_for_status()
+
+        qc_id = response.json()["id"]
+
+        preview_url = self.smart_insight_url + "/composed_queries/" + qc_id + "/preview"
+
+        logging.info("CALLING {}".format(preview_url))
+
+        s = requests.Session()
+        s.keep_alive = False
+        retries = Retry(total=5, backoff_factor=1, status_forcelist=[502, 503, 504])
+        s.mount('https://', HTTPAdapter(max_retries=retries))
+
+        headers = {"Authorization": "Bearer" + " " + self._token}
+        response = s.post(url=preview_url, json={}, headers=headers)
+        response.raise_for_status()
+
+        r = response.json()
+        return pd.DataFrame(r['data'])
+
+
+
     def update_parquet_dataset(self, agent_slug, dataset_id, file_path, strategy):
 
         s = requests.Session()
