@@ -77,6 +77,9 @@ class Insight_Definition:
                         else:
                             settings[field + "_id"] = column["id"]
                             break
+                #Case when a value that is not a column is passed
+                else:
+                    settings[field + "_id"] = field_codes[field]
 
         body = {
             "id" : widget_id,
